@@ -11,4 +11,6 @@ class APIResponseError(FoxtrotError):
   pass
 
 class APITimeoutError(FoxtrotError):
-  pass
+  def __init__(self, count):
+    self.count = count
+    super(APITimeoutError, self).__init__("Request timed out after {} seconds.".format(count))
